# Apple Health Parser

![logo](https://raw.githubusercontent.com/alxdrcirilo/apple-health-parser/main/docs/assets/images/header.svg)

[![commit lint and release - workflow](https://github.com/alxdrcirilo/apple-health-parser/actions/workflows/release.yaml/badge.svg?event=workflow_run)](https://github.com/alxdrcirilo/apple-health-parser/actions/workflows/release.yaml)
[![coverage - workflow](https://github.com/alxdrcirilo/apple-health-parser/actions/workflows/coverage.yaml/badge.svg?event=workflow_run)](https://github.com/alxdrcirilo/apple-health-parser/actions/workflows/coverage.yaml)
[![coverage](https://coveralls.io/repos/github/alxdrcirilo/apple-health-parser/badge.svg?branch=main)](https://coveralls.io/github/alxdrcirilo/apple-health-parser?branch=main)
[![python version](https://img.shields.io/badge/python-3.11|3.12-blue)](https://www.python.org/)
[![poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
[![ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![license](https://img.shields.io/badge/license-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
<!-- TODO: Check supported Python versions -->
<!-- TODO: Add PyPi URL -->
<!-- TODO: Add PyPi monthly downloads -->

The *Apple Health Parser* Python package simplifies the extraction and analysis of health data exported from [Apple HealthKit](https://developer.apple.com/documentation/healthkit). Designed for seamless integration into data science workflows and health analytics applications, this package offers robust parsing and plotting capabilities for various health metrics stored in the Apple Health export XML format.

> :warning: This package is still in active development and has not been tested on real data coming from different sources, nor has it been tested with data originating from versions of iOS < 17.
